@@ -9,8 +9,8 @@
 #include "kwin_wayland_test.h"
 
 #include "compositor.h"
-#include "effectloader.h"
-#include "effects.h"
+#include "effect/effecthandler.h"
+#include "effect/effectloader.h"
 #include "pointer_input.h"
 #include "virtualdesktops.h"
 #include "wayland_server.h"
@@ -59,8 +59,8 @@ void TranslucencyTest::initTestCase()
     for (QString name : builtinNames) {
         plugins.writeEntry(name + QStringLiteral("Enabled"), false);
     }
-    config->group("Outline").writeEntry(QStringLiteral("QmlPath"), QString("/does/not/exist.qml"));
-    config->group("Effect-translucency").writeEntry(QStringLiteral("Dialogs"), 90);
+    config->group(QStringLiteral("Outline")).writeEntry(QStringLiteral("QmlPath"), QString("/does/not/exist.qml"));
+    config->group(QStringLiteral("Effect-translucency")).writeEntry(QStringLiteral("Dialogs"), 90);
 
     config->sync();
     kwinApp()->setConfig(config);
@@ -73,16 +73,14 @@ void TranslucencyTest::initTestCase()
 
 void TranslucencyTest::init()
 {
-    // load the translucency effect
-    EffectsHandlerImpl *e = static_cast<EffectsHandlerImpl *>(effects);
     // find the effectsloader
-    auto effectloader = e->findChild<AbstractEffectLoader *>();
+    auto effectloader = effects->findChild<AbstractEffectLoader *>();
     QVERIFY(effectloader);
     QSignalSpy effectLoadedSpy(effectloader, &AbstractEffectLoader::effectLoaded);
 
-    QVERIFY(!e->isEffectLoaded(QStringLiteral("translucency")));
-    QVERIFY(e->loadEffect(QStringLiteral("translucency")));
-    QVERIFY(e->isEffectLoaded(QStringLiteral("translucency")));
+    QVERIFY(!effects->isEffectLoaded(QStringLiteral("translucency")));
+    QVERIFY(effects->loadEffect(QStringLiteral("translucency")));
+    QVERIFY(effects->isEffectLoaded(QStringLiteral("translucency")));
 
     QCOMPARE(effectLoadedSpy.count(), 1);
     m_translucencyEffect = effectLoadedSpy.first().first().value<Effect *>();
@@ -91,11 +89,10 @@ void TranslucencyTest::init()
 
 void TranslucencyTest::cleanup()
 {
-    EffectsHandlerImpl *e = static_cast<EffectsHandlerImpl *>(effects);
-    if (e->isEffectLoaded(QStringLiteral("translucency"))) {
-        e->unloadEffect(QStringLiteral("translucency"));
+    if (effects->isEffectLoaded(QStringLiteral("translucency"))) {
+        effects->unloadEffect(QStringLiteral("translucency"));
     }
-    QVERIFY(!e->isEffectLoaded(QStringLiteral("translucency")));
+    QVERIFY(!effects->isEffectLoaded(QStringLiteral("translucency")));
     m_translucencyEffect = nullptr;
 }
 
