@@ -279,7 +279,7 @@ void TouchInputTest::testUpdateFocusOnDecorationDestroy()
     QSignalSpy sequenceEndedSpy(m_touch, &KWayland::Client::Touch::sequenceEnded);
 
     // Enable the borderless maximized windows option.
-    auto group = kwinApp()->config()->group("Windows");
+    auto group = kwinApp()->config()->group(QStringLiteral("Windows"));
     group.writeEntry("BorderlessMaximizedWindows", true);
     group.sync();
     Workspace::self()->slotReconfigure();
@@ -359,6 +359,11 @@ void TouchInputTest::testUpdateFocusOnDecorationDestroy()
 
 void TouchInputTest::testGestureDetection()
 {
+#if !KWIN_BUILD_GLOBALSHORTCUTS
+    QSKIP("Can't test shortcuts without shortcuts");
+    return;
+#endif
+
     bool callbackTriggered = false;
     const auto callback = [&callbackTriggered](float progress) {
         callbackTriggered = true;
