@@ -27,16 +27,21 @@ RenderLoop *DrmAbstractOutput::renderLoop() const
     return m_renderLoop.get();
 }
 
-void DrmAbstractOutput::frameFailed() const
+void DrmAbstractOutput::frameFailed()
 {
-    m_frame->failed();
+    if (m_frame) {
+        m_frame->failed();
+        m_frame.reset();
+    }
 }
 
 void DrmAbstractOutput::pageFlipped(std::chrono::nanoseconds timestamp, PresentationMode mode)
 {
-    const auto gpuTime = primaryLayer() ? primaryLayer()->queryRenderTime() : std::chrono::nanoseconds::zero();
-    m_frame->presented(std::chrono::nanoseconds(1'000'000'000'000 / refreshRate()), timestamp, gpuTime, mode);
-    m_frame.reset();
+    if (m_frame) {
+        const auto gpuTime = primaryLayer() ? primaryLayer()->queryRenderTime() : std::chrono::nanoseconds::zero();
+        m_frame->presented(std::chrono::nanoseconds(1'000'000'000'000 / refreshRate()), timestamp, gpuTime, mode);
+        m_frame.reset();
+    }
 }
 
 DrmGpu *DrmAbstractOutput::gpu() const
