@@ -136,9 +136,10 @@ std::shared_ptr<GLTexture> VirtualEglGbmLayer::texture() const
 {
     if (m_scanoutSurface) {
         return m_eglBackend->importDmaBufAsTexture(*m_scanoutBuffer->dmabufAttributes());
-    } else {
+    } else if (m_currentSlot) {
         return m_currentSlot->texture();
     }
+    return nullptr;
 }
 
 bool VirtualEglGbmLayer::scanout(SurfaceItem *surfaceItem)
@@ -183,14 +184,6 @@ void VirtualEglGbmLayer::releaseBuffers()
     }
 }
 
-quint32 VirtualEglGbmLayer::format() const
-{
-    if (!m_gbmSwapchain) {
-        return DRM_FORMAT_ARGB8888;
-    }
-    return m_gbmSwapchain->format();
-}
-
 std::chrono::nanoseconds VirtualEglGbmLayer::queryRenderTime() const
 {
     m_eglBackend->makeCurrent();
