@@ -462,7 +462,7 @@ QRect Output::geometry() const
     return QRect(m_state.position, pixelSize() / scale());
 }
 
-QRectF Output::fractionalGeometry() const
+QRectF Output::geometryF() const
 {
     return QRectF(m_state.position, QSizeF(pixelSize()) / scale());
 }
@@ -619,6 +619,9 @@ void Output::setState(const State &state)
     if (oldState.vrrPolicy != state.vrrPolicy) {
         Q_EMIT vrrPolicyChanged();
     }
+    if (oldState.colorDescription != state.colorDescription) {
+        Q_EMIT colorDescriptionChanged();
+    }
     if (oldState.enabled != state.enabled) {
         Q_EMIT enabledChanged();
     }
