@@ -14,7 +14,21 @@
 
 namespace KWin
 {
+
 class Output;
+class RegionScreenCastSource;
+
+class RegionScreenCastScrapper : public QObject
+{
+    Q_OBJECT
+
+public:
+    explicit RegionScreenCastScrapper(RegionScreenCastSource *source, Output *output);
+
+private:
+    RegionScreenCastSource *m_source;
+    Output *m_output;
+};
 
 class RegionScreenCastSource : public ScreenCastSource
 {
@@ -22,6 +36,7 @@ class RegionScreenCastSource : public ScreenCastSource
 
 public:
     explicit RegionScreenCastSource(const QRect &region, qreal scale, QObject *parent = nullptr);
+    ~RegionScreenCastSource() override;
 
     quint32 drmFormat() const override;
     bool hasAlphaChannel() const override;
@@ -32,24 +47,23 @@ public:
     void render(spa_data *spa, spa_video_format format) override;
     std::chrono::nanoseconds clock() const override;
 
-    QRect region() const
-    {
-        return m_region;
-    }
-    qreal scale() const
-    {
-        return m_scale;
-    }
-    void updateOutput(Output *output);
+    void update(Output *output, const QRegion &damage);
+    void close();
+    void pause() override;
+    void resume() override;
 
 private:
+    void blit(Output *output);
     void ensureTexture();
 
     const QRect m_region;
     const qreal m_scale;
+    std::vector<std::unique_ptr<RegionScreenCastScrapper>> m_scrappers;
     std::unique_ptr<GLFramebuffer> m_target;
     std::unique_ptr<GLTexture> m_renderedTexture;
     std::chrono::nanoseconds m_last;
+    bool m_closed = false;
+    bool m_active = false;
 };
 
 } // namespace KWin
