@@ -194,11 +194,6 @@ void ScreenCastStream::onStreamParamChanged(uint32_t id, const struct spa_pod *f
                 for (uint64_t modifier : receivedModifiers) {
                     m_modifiers.removeAll(modifier);
                 }
-            // Also in case DRM_FORMAT_MOD_INVALID was used and didn't fail, we still need to
-            // set it as our modifier, otherwise it would be set to default value (0) which is
-            // also a valid modifier, but not the one we want to actually use
-            } else if (receivedModifiers.count() == 1 && receivedModifiers.constFirst() == DRM_FORMAT_MOD_INVALID) {
-                m_dmabufParams->modifier = DRM_FORMAT_MOD_INVALID;
             }
 
             qCDebug(KWIN_SCREENCAST) << "Stream dmabuf modifiers received, offering our best suited modifier" << m_dmabufParams.has_value();
@@ -232,20 +227,23 @@ void ScreenCastStream::onStreamAddBuffer(pw_buffer *buffer)
 
     if (dmabuff) {
         const DmaBufAttributes *dmabufAttribs = dmabuff->buffer()->dmabufAttributes();
-        Q_ASSERT(buffer->buffer->n_datas >= uint(dmabufAttribs->planeCount));
-        for (int i = 0; i < dmabufAttribs->planeCount; ++i) {
-            spa_data[i].type = SPA_DATA_DmaBuf;
-            spa_data[i].flags = SPA_DATA_FLAG_READWRITE;
-            spa_data[i].mapoffset = 0;
-            spa_data[i].maxsize = i == 0 ? dmabufAttribs->pitch[i] * dmabufAttribs->height : 0; // TODO: dmabufs don't have a well defined size, it should be zero but some clients check the size to see if the buffer is valid
-            spa_data[i].fd = dmabufAttribs->fd[i].get();
-            spa_data[i].data = nullptr;
-            spa_data[i].chunk->offset = dmabufAttribs->offset[i];
-            spa_data[i].chunk->size = spa_data[i].maxsize;
-            spa_data[i].chunk->stride = dmabufAttribs->pitch[i];
-            spa_data[i].chunk->flags = SPA_CHUNK_FLAG_NONE;
+        if (buffer->buffer->n_datas != uint32_t(dmabufAttribs->planeCount)) {
+            qCWarning(KWIN_SCREENCAST, "Dmabuf buffer has invalid n_datas: got %d, expected %d", buffer->buffer->n_datas, dmabufAttribs->planeCount);
+        } else {
+            for (int i = 0; i < dmabufAttribs->planeCount; ++i) {
+                spa_data[i].type = SPA_DATA_DmaBuf;
+                spa_data[i].flags = SPA_DATA_FLAG_READWRITE;
+                spa_data[i].mapoffset = 0;
+                spa_data[i].maxsize = i == 0 ? dmabufAttribs->pitch[i] * dmabufAttribs->height : 0; // TODO: dmabufs don't have a well defined size, it should be zero but some clients check the size to see if the buffer is valid
+                spa_data[i].fd = dmabufAttribs->fd[i].get();
+                spa_data[i].data = nullptr;
+                spa_data[i].chunk->offset = dmabufAttribs->offset[i];
+                spa_data[i].chunk->size = spa_data[i].maxsize;
+                spa_data[i].chunk->stride = dmabufAttribs->pitch[i];
+                spa_data[i].chunk->flags = SPA_CHUNK_FLAG_NONE;
+            }
+            m_dmabufDataForPwBuffer.insert(buffer, dmabuff);
         }
-        m_dmabufDataForPwBuffer.insert(buffer, dmabuff);
 #ifdef F_SEAL_SEAL // Disable memfd on systems that don't have it, like BSD < 12
     } else {
         if (!(spa_data->type & (1 << SPA_DATA_MemFd))) {
@@ -357,6 +355,10 @@ ScreenCastStream::ScreenCastStream(ScreenCastSource *source, std::shared_ptr<Pip
 ScreenCastStream::~ScreenCastStream()
 {
     m_closed = true;
+
+    if (m_pwRenegotiate) {
+        pw_loop_destroy_source(m_pwCore->pwMainLoop, m_pwRenegotiate);
+    }
     if (m_pwStream) {
         pw_stream_destroy(m_pwStream);
     }
@@ -541,7 +543,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
         uint8_t *data = static_cast<uint8_t *>(spa_data->data);
         if (!data) {
             qCWarning(KWIN_SCREENCAST) << "Failed to record frame: invalid buffer data";
-            spa_data->chunk->flags = SPA_CHUNK_FLAG_CORRUPTED;
+            corruptHeader(spa_buffer);
             pw_stream_queue_buffer(m_pwStream, buffer);
             return;
         }
@@ -552,7 +554,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
 
         if ((stride * size.height()) > spa_data->maxsize) {
             qCDebug(KWIN_SCREENCAST) << "Failed to record frame: frame is too big";
-            spa_data->chunk->flags = SPA_CHUNK_FLAG_CORRUPTED;
+            corruptHeader(spa_buffer);
             pw_stream_queue_buffer(m_pwStream, buffer);
             return;
         }
@@ -571,7 +573,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
         auto dmabuf = m_dmabufDataForPwBuffer.constFind(buffer);
         if (dmabuf == m_dmabufDataForPwBuffer.constEnd()) {
             qCDebug(KWIN_SCREENCAST) << "Failed to record frame: no dmabuf data";
-            spa_data->chunk->flags = SPA_CHUNK_FLAG_CORRUPTED;
+            corruptHeader(spa_buffer);
             pw_stream_queue_buffer(m_pwStream, buffer);
             return;
         }
@@ -625,7 +627,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
         }
     } else {
         qCWarning(KWIN_SCREENCAST, "Failed to record frame: invalid buffer type: %d", spa_data[0].type);
-        spa_data->chunk->flags = SPA_CHUNK_FLAG_CORRUPTED;
+        corruptHeader(spa_buffer);
         pw_stream_queue_buffer(m_pwStream, buffer);
         return;
     }
@@ -642,7 +644,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
 
 void ScreenCastStream::addHeader(spa_buffer *spaBuffer)
 {
-    spa_meta_header *spaHeader = (spa_meta_header *)spa_buffer_find_meta_data(spaBuffer, SPA_META_Header, sizeof(spaHeader));
+    spa_meta_header *spaHeader = (spa_meta_header *)spa_buffer_find_meta_data(spaBuffer, SPA_META_Header, sizeof(spa_meta_header));
     if (spaHeader) {
         spaHeader->flags = 0;
         spaHeader->dts_offset = 0;
@@ -651,6 +653,14 @@ void ScreenCastStream::addHeader(spa_buffer *spaBuffer)
     }
 }
 
+void ScreenCastStream::corruptHeader(spa_buffer *spaBuffer)
+{
+    spa_meta_header *spaHeader = (spa_meta_header *)spa_buffer_find_meta_data(spaBuffer, SPA_META_Header, sizeof(spa_meta_header));
+    if (spaHeader) {
+        spaHeader->flags = SPA_META_HEADER_FLAG_CORRUPTED;
+    }
+}
+
 void ScreenCastStream::addDamage(spa_buffer *spaBuffer, const QRegion &damagedRegion)
 {
     if (spa_meta *vdMeta = spa_buffer_find_meta(spaBuffer, SPA_META_VideoDamage)) {
