@@ -16,14 +16,6 @@
 
 namespace KWin
 {
-
-class ZoomEffectConfigForm : public QWidget, public Ui::ZoomEffectConfigForm
-{
-    Q_OBJECT
-public:
-    explicit ZoomEffectConfigForm(QWidget *parent = nullptr);
-};
-
 class ZoomEffectConfig : public KCModule
 {
     Q_OBJECT
@@ -34,7 +26,7 @@ public Q_SLOTS:
     void save() override;
 
 private:
-    ZoomEffectConfigForm *m_ui;
+    Ui::ZoomEffectConfigForm m_ui;
     enum MouseTracking {
         MouseCentred = 0,
         MouseProportional = 1,
