@@ -33,7 +33,8 @@ namespace KWin
 {
 
 Rules::Rules()
-    : wmclassmatch(UnimportantMatch)
+    : layerrule(UnusedForceRule)
+    , wmclassmatch(UnimportantMatch)
     , wmclasscomplete(UnimportantMatch)
     , windowrolematch(UnimportantMatch)
     , titlematch(UnimportantMatch)
@@ -50,7 +51,6 @@ Rules::Rules()
     , desktopsrule(UnusedSetRule)
     , screenrule(UnusedSetRule)
     , activityrule(UnusedSetRule)
-    , typerule(UnusedForceRule)
     , maximizevertrule(UnusedSetRule)
     , maximizehorizrule(UnusedSetRule)
     , minimizerule(UnusedSetRule)
@@ -127,10 +127,6 @@ void Rules::readFromSettings(const RuleSettings *settings)
     READ_SET_RULE(desktops);
     READ_SET_RULE(screen);
     READ_SET_RULE(activity);
-    READ_FORCE_RULE(type, static_cast<NET::WindowType>);
-    if (type == NET::Unknown) {
-        typerule = UnusedForceRule;
-    }
     READ_SET_RULE(maximizevert);
     READ_SET_RULE(maximizehoriz);
     READ_SET_RULE(minimize);
@@ -160,6 +156,7 @@ void Rules::readFromSettings(const RuleSettings *settings)
     READ_SET_RULE(shortcut);
     READ_FORCE_RULE(disableglobalshortcuts, );
     READ_SET_RULE(desktopfile);
+    READ_FORCE_RULE(layer, );
 }
 
 #undef READ_MATCH_STRING
@@ -206,7 +203,6 @@ void Rules::write(RuleSettings *settings) const
     WRITE_SET_RULE(desktops, Desktops, );
     WRITE_SET_RULE(screen, Screen, );
     WRITE_SET_RULE(activity, Activity, );
-    WRITE_FORCE_RULE(type, Type, );
     WRITE_SET_RULE(maximizevert, Maximizevert, );
     WRITE_SET_RULE(maximizehoriz, Maximizehoriz, );
     WRITE_SET_RULE(minimize, Minimize, );
@@ -238,6 +234,7 @@ void Rules::write(RuleSettings *settings) const
     WRITE_SET_RULE(shortcut, Shortcut, );
     WRITE_FORCE_RULE(disableglobalshortcuts, Disableglobalshortcuts, );
     WRITE_SET_RULE(desktopfile, Desktopfile, );
+    WRITE_FORCE_RULE(layer, Layer, );
 }
 
 #undef WRITE_MATCH_STRING
@@ -258,7 +255,6 @@ bool Rules::isEmpty() const
             && desktopsrule == UnusedSetRule
             && screenrule == UnusedSetRule
             && activityrule == UnusedSetRule
-            && typerule == UnusedForceRule
             && maximizevertrule == UnusedSetRule
             && maximizehorizrule == UnusedSetRule
             && minimizerule == UnusedSetRule
@@ -282,7 +278,8 @@ bool Rules::isEmpty() const
             && strictgeometryrule == UnusedForceRule
             && shortcutrule == UnusedSetRule
             && disableglobalshortcutsrule == UnusedForceRule
-            && desktopfilerule == UnusedSetRule);
+            && desktopfilerule == UnusedSetRule
+            && layerrule == UnusedForceRule);
 }
 
 Rules::ForceRule Rules::convertForceRule(int v)
@@ -395,7 +392,7 @@ bool Rules::matchClientMachine(const QString &match_machine, bool local) const
 #ifndef KCMRULES
 bool Rules::match(const Window *c) const
 {
-    if (!matchType(c->windowType(true))) {
+    if (!matchType(c->windowType())) {
         return false;
     }
     if (!matchWMClass(c->resourceClass(), c->resourceName())) {
@@ -408,10 +405,7 @@ bool Rules::match(const Window *c) const
         return false;
     }
     if (titlematch != UnimportantMatch) { // track title changes to rematch rules
-        QObject::connect(c, &Window::captionChanged, c, &Window::evaluateWindowRules,
-                         // QueuedConnection, because title may change before
-                         // the client is ready (could segfault!)
-                         static_cast<Qt::ConnectionType>(Qt::QueuedConnection | Qt::UniqueConnection));
+        QObject::connect(c, &Window::captionNormalChanged, c, &Window::evaluateWindowRules, Qt::UniqueConnection);
     }
     if (!matchTitle(c->captionNormal())) {
         return false;
@@ -577,7 +571,7 @@ APPLY_RULE(ignoregeometry, IgnoreGeometry, bool)
 
 APPLY_RULE(screen, Screen, int)
 APPLY_RULE(activity, Activity, QStringList)
-APPLY_FORCE_RULE(type, Type, NET::WindowType)
+APPLY_FORCE_RULE(layer, Layer, enum Layer)
 
 bool Rules::applyDesktops(QList<VirtualDesktop *> &vds, bool init) const
 {
@@ -676,7 +670,6 @@ bool Rules::discardUsed(bool withdrawn)
     DISCARD_USED_SET_RULE(desktops);
     DISCARD_USED_SET_RULE(screen);
     DISCARD_USED_SET_RULE(activity);
-    DISCARD_USED_FORCE_RULE(type);
     DISCARD_USED_SET_RULE(maximizevert);
     DISCARD_USED_SET_RULE(maximizehoriz);
     DISCARD_USED_SET_RULE(minimize);
@@ -701,6 +694,7 @@ bool Rules::discardUsed(bool withdrawn)
     DISCARD_USED_SET_RULE(shortcut);
     DISCARD_USED_FORCE_RULE(disableglobalshortcuts);
     DISCARD_USED_SET_RULE(desktopfile);
+    DISCARD_USED_FORCE_RULE(layer);
 
     return changed;
 }
@@ -781,7 +775,7 @@ QPointF WindowRules::checkPositionSafe(QPointF pos, bool init) const
     }
     const auto outputs = workspace()->outputs();
     const bool inAnyOutput = std::any_of(outputs.begin(), outputs.end(), [ret](const auto output) {
-        return output->fractionalGeometry().contains(ret);
+        return output->geometryF().contains(ret);
     });
     if (inAnyOutput) {
         return ret;
@@ -800,7 +794,6 @@ CHECK_RULE(IgnoreGeometry, bool)
 
 CHECK_RULE(Desktops, QList<VirtualDesktop *>)
 CHECK_RULE(Activity, QStringList)
-CHECK_FORCE_RULE(Type, NET::WindowType)
 CHECK_RULE(MaximizeVert, MaximizeMode)
 CHECK_RULE(MaximizeHoriz, MaximizeMode)
 
@@ -848,6 +841,7 @@ CHECK_FORCE_RULE(StrictGeometry, bool)
 CHECK_RULE(Shortcut, QString)
 CHECK_FORCE_RULE(DisableGlobalShortcuts, bool)
 CHECK_RULE(DesktopFile, QString)
+CHECK_FORCE_RULE(Layer, Layer)
 
 #undef CHECK_RULE
 #undef CHECK_FORCE_RULE
