@@ -53,7 +53,6 @@ public:
     QList<VirtualDesktop *> checkDesktops(QList<VirtualDesktop *> desktops, bool init = false) const;
     Output *checkOutput(Output *output, bool init = false) const;
     QStringList checkActivity(QStringList activity, bool init = false) const;
-    NET::WindowType checkType(NET::WindowType type) const;
     MaximizeMode checkMaximize(MaximizeMode mode, bool init = false) const;
     bool checkMinimize(bool minimized, bool init = false) const;
     ShadeMode checkShade(ShadeMode shade, bool init = false) const;
@@ -77,6 +76,7 @@ public:
     QString checkShortcut(QString s, bool init = false) const;
     bool checkDisableGlobalShortcuts(bool disable) const;
     QString checkDesktopFile(QString desktopFile, bool init = false) const;
+    Layer checkLayer(Layer layer) const;
 
 private:
     MaximizeMode checkMaximizeVert(MaximizeMode mode, bool init) const;
@@ -111,6 +111,7 @@ public:
         Activity = 1 << 16,
         Screen = 1 << 17,
         DesktopFile = 1 << 18,
+        Layer = 1 << 19,
         All = 0xffffffff
     };
     Q_DECLARE_FLAGS(Types, Type)
@@ -159,7 +160,6 @@ public:
     bool applyDesktops(QList<VirtualDesktop *> &desktops, bool init) const;
     bool applyScreen(int &desktop, bool init) const;
     bool applyActivity(QStringList &activity, bool init) const;
-    bool applyType(NET::WindowType &type) const;
     bool applyMaximizeVert(MaximizeMode &mode, bool init) const;
     bool applyMaximizeHoriz(MaximizeMode &mode, bool init) const;
     bool applyMinimize(bool &minimized, bool init) const;
@@ -184,6 +184,7 @@ public:
     bool applyShortcut(QString &shortcut, bool init) const;
     bool applyDisableGlobalShortcuts(bool &disable) const;
     bool applyDesktopFile(QString &desktopFile, bool init) const;
+    bool applyLayer(enum Layer &layer) const;
 
 private:
 #endif
@@ -204,6 +205,8 @@ private:
     static bool checkSetStop(SetRule rule);
     static bool checkForceStop(ForceRule rule);
 #endif
+    enum Layer layer;
+    ForceRule layerrule;
     QString description;
     QString wmclass;
     StringMatch wmclassmatch;
@@ -237,8 +240,6 @@ private:
     SetRule screenrule;
     QStringList activity;
     SetRule activityrule;
-    NET::WindowType type; // type for setting
-    ForceRule typerule;
     bool maximizevert;
     SetRule maximizevertrule;
     bool maximizehoriz;
