@@ -9,6 +9,7 @@
 #include "plasmavirtualdesktop.h"
 #include "surface.h"
 #include "utils/common.h"
+#include "wayland/quirks.h"
 
 #include <QFile>
 #include <QHash>
@@ -26,19 +27,6 @@ namespace KWin
 static const quint32 s_version = 16;
 static const quint32 s_activationVersion = 1;
 
-// any strings that come from user-defined sources
-// that could exceed the maximum wayland length (i.e xwayland clients)
-// need to be truncated to the maximumWaylandBufferSize
-static QString truncate(const QString &stringIn)
-{
-    const int libwaylandMaxBufferSize = 4096;
-    // Some parts of the buffer is used for metadata, so subtract 100 to be on the safe side.
-    // Also, QString is in utf-16, which means that in the worst case each character will be
-    // three bytes when converted to utf-8 (which is what libwayland uses), so divide by three.
-    const int maxLength = libwaylandMaxBufferSize / 3 - 100;
-    return stringIn.left(maxLength);
-}
-
 class PlasmaWindowManagementInterfacePrivate : public QtWaylandServer::org_kde_plasma_window_management
 {
 public:
