@@ -73,7 +73,7 @@
 #include "wayland/xdgtopleveldrag_v1.h"
 #include "wayland/xwaylandkeyboardgrab_v1.h"
 #include "wayland/xwaylandshell_v1.h"
-#include "wayland/xx_colormanagement_v1.h"
+#include "wayland/xx_colormanagement_v2.h"
 #include "workspace.h"
 #include "x11window.h"
 #include "xdgactivationv1.h"
@@ -388,8 +388,7 @@ bool WaylandServer::init(InitializationFlags flags)
     }
 
     m_idle = new IdleInterface(m_display, m_display);
-    auto idleInhibition = new IdleInhibition(m_idle);
-    connect(this, &WaylandServer::windowAdded, idleInhibition, &IdleInhibition::registerClient);
+    new IdleInhibition(m_idle);
     new IdleInhibitManagerV1Interface(m_display, m_display);
     new IdleNotifyV1Interface(m_display, m_display);
     m_plasmaShell = new PlasmaShellInterface(m_display, m_display);
@@ -491,7 +490,7 @@ bool WaylandServer::init(InitializationFlags flags)
     new FrogColorManagementV1(m_display, m_display);
     new PresentationTime(m_display, m_display);
     if (qEnvironmentVariableIntValue("KWIN_ENABLE_XX_COLOR_MANAGEMENT")) {
-        m_xxColorManager = new XXColorManagerV1(m_display, m_display);
+        m_xxColorManager = new XXColorManagerV2(m_display, m_display);
     }
     return true;
 }
