@@ -270,12 +270,30 @@ private:
     // Unsorted
 
 public:
-    // True when performing Workspace::updateClientArea().
-    // The calls below are valid only in that case.
-    bool inUpdateClientArea() const;
     StrutRects previousRestrictedMoveArea(const VirtualDesktop *desktop, StrutAreas areas = StrutAreaAll) const;
     QHash<const Output *, QRect> previousScreenSizes() const;
 
+    /**
+     * Returns @c true if the workspace is currently being rearranged; otherwise returns @c false.
+     */
+    bool inRearrange() const;
+
+    /**
+     * Re-arranges the workspace, it includes computing restricted areas, moving windows out of the
+     * restricted areas, and so on.
+     *
+     * The client area is the area that is available for windows (that which is not taken by windows
+     * like panels, the top-of-screen menu etc).
+     *
+     * @see clientArea()
+     */
+    void rearrange();
+
+    /**
+     * Schedules the workspace to be re-arranged at the next available opportunity.
+     */
+    void scheduleRearrange();
+
     /**
      * Returns the list of windows sorted in stacking order, with topmost window
      * at the last position
@@ -516,8 +534,6 @@ public Q_SLOTS:
     void slotSetupWindowShortcut();
     void setupWindowShortcutDone(bool);
 
-    void updateClientArea();
-
 private Q_SLOTS:
     void desktopResized();
     void selectWmInputEventMask();
@@ -563,6 +579,7 @@ Q_SIGNALS:
      * or lowered
      */
     void stackingOrderChanged();
+    void aboutToRearrange();
 
 private:
     void init();
@@ -695,7 +712,8 @@ private:
 
     QHash<const Output *, QRect> m_oldScreenGeometries;
     QHash<const VirtualDesktop *, StrutRects> m_oldRestrictedAreas;
-    bool m_inUpdateClientArea = false;
+    QTimer m_rearrangeTimer;
+    bool m_inRearrange = false;
 
     int m_setActiveWindowRecursion = 0;
     int m_blockStackingUpdates = 0; // When > 0, stacking updates are temporarily disabled
